@@ -35,6 +35,11 @@
 
 #include <stdio.h>
 #include <stddef.h>
+#ifdef HAVE_LIBBSD
+# include <bsd/stdio.h>
+# include <bsd/string.h>
+# include <bsd/unistd.h>
+#endif
 
 #if !HAVE_STRLCPY
 size_t	strlcpy(char *, const char *, size_t);
@@ -48,6 +53,10 @@ size_t	strnlen(const char *, size_t);
 char *fgetln(FILE *, size_t *);
 #endif
 
+#if !HAVE_SETPROCTITLE
+void setproctitle(const char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
+#endif
+
 #if !HAVE_MALLOC
 void *malloc(size_t size);
 #endif
