@@ -33,7 +33,7 @@ client_handle_get_configuration(struct lldpd *cfg, enum hmsg_type *type,
 {
 	ssize_t output_len;
 	log_debug("rpc", "client requested configuration");
-	output_len = marshal_serialize(lldpd_config, &cfg->g_config, output);
+	output_len = lldpd_config_serialize(&cfg->g_config, output);
 	if (output_len <= 0) {
 		output_len = 0;
 		*type = NONE;
@@ -47,21 +47,28 @@ client_handle_set_configuration(struct lldpd *cfg, enum hmsg_type *type,
     void *input, int input_len, void **output, int *subscribed)
 {
 	struct lldpd_config *config;
-	void *p;
 
 	log_debug("rpc", "client request a change in configuration");
 	/* Get the proposed configuration. */
-	if (marshal_unserialize(lldpd_config, input, input_len, &p) <= 0) {
+	if (lldpd_config_unserialize(input, input_len, &config) <= 0) {
 		*type = NONE;
 		return 0;
 	}
-	config = p;
-
+	
 	/* What needs to be done? Transmit delay? */
 	if (config->c_tx_interval > 0) {
 		log_debug("rpc", "client change transmit interval to %d",
 			config->c_tx_interval);
 		cfg->g_config.c_tx_interval = config->c_tx_interval;
+		LOCAL_CHASSIS(cfg)->c_ttl = cfg->g_config.c_tx_interval *
+			cfg->g_config.c_tx_hold;
+	}
+	if (config->c_tx_hold > 0) {
+		log_debug("rpc", "client change transmit hold to %d",
+			config->c_tx_hold);
+		cfg->g_config.c_tx_hold = config->c_tx_hold;
+		LOCAL_CHASSIS(cfg)->c_ttl = cfg->g_config.c_tx_interval *
+			cfg->g_config.c_tx_hold;
 	}
 	if (config->c_tx_interval < 0) {
 		log_debug("rpc", "client asked for immediate retransmission");
@@ -75,7 +82,38 @@ client_handle_set_configuration(struct lldpd *cfg, enum hmsg_type *type,
 		levent_send_now(cfg);
 	}
 
+#ifdef ENABLE_LLDPMED
+	if (config->c_enable_fast_start) {
+		cfg->g_config.c_enable_fast_start = (config->c_enable_fast_start == 1);
+		log_debug("rpc", "client asked to %s fast start",
+		    cfg->g_config.c_enable_fast_start?"enable":"disable");
+	}
+	if (config->c_tx_fast_interval) {
+		log_debug("rpc", "change fast interval to %d", config->c_tx_fast_interval);
+		cfg->g_config.c_tx_fast_interval = config->c_tx_fast_interval;
+	}
+#endif
+	if (config->c_iface_pattern) {
+		log_debug("rpc", "change interface pattern to %s", config->c_iface_pattern);
+		free(cfg->g_config.c_iface_pattern);
+		cfg->g_config.c_iface_pattern = strdup(config->c_iface_pattern);
+		levent_update_now(cfg);
+	}
+	if (config->c_description) {
+		log_debug("rpc", "change chassis description to %s", config->c_description);
+		free(cfg->g_config.c_description);
+		cfg->g_config.c_description = strdup(config->c_description);
+		levent_update_now(cfg);
+	}
+	if (config->c_platform) {
+		log_debug("rpc", "change platform description to %s", config->c_platform);
+		free(cfg->g_config.c_platform);
+		cfg->g_config.c_platform = strdup(config->c_platform);
+		levent_update_now(cfg);
+	}
+
 	lldpd_config_cleanup(config);
+	free(config);
 
 	return 0;
 }
@@ -105,7 +143,7 @@ client_handle_get_interfaces(struct lldpd *cfg, enum hmsg_type *type,
 		TAILQ_INSERT_TAIL(&ifs, iff, next);
 	}
 
-	output_len = marshal_serialize(lldpd_interface_list, &ifs, output);
+	output_len = lldpd_interface_list_serialize(&ifs, output);
 	if (output_len <= 0) {
 		output_len = 0;
 		*type = NONE;
@@ -132,8 +170,8 @@ client_handle_get_interface(struct lldpd *cfg, enum hmsg_type *type,
     void *input, int input_len, void **output, int *subscribed)
 {
 	char *name;
-	void *p;
 	struct lldpd_hardware *hardware;
+	void *p;
 
 	/* Get name of the interface */
 	if (marshal_unserialize(string, input, input_len, &p) <= 0) {
@@ -146,7 +184,7 @@ client_handle_get_interface(struct lldpd *cfg, enum hmsg_type *type,
 	log_debug("rpc", "client request interface %s", name);
 	TAILQ_FOREACH(hardware, &cfg->g_hardware, h_entries)
 		if (!strcmp(hardware->h_ifname, name)) {
-			int output_len = marshal_serialize(lldpd_hardware, hardware, output);
+			int output_len = lldpd_hardware_serialize(hardware, output);
 			free(name);
 			if (output_len <= 0) {
 				*type = NONE;
@@ -170,18 +208,16 @@ client_handle_set_port(struct lldpd *cfg, enum hmsg_type *type,
     void *input, int input_len, void **output, int *subscribed)
 {
 	int ret = 0;
-	void *p;
 	struct lldpd_port_set *set = NULL;
 	struct lldpd_hardware *hardware = NULL;
 #ifdef ENABLE_LLDPMED
 	struct lldpd_med_loc *loc = NULL;
 #endif
 
-	if (marshal_unserialize(lldpd_port_set, input, input_len, &p) <= 0) {
+	if (lldpd_port_set_unserialize(input, input_len, &set) <= 0) {
 		*type = NONE;
 		return 0;
 	}
-	set = p;
 	if (!set->ifname) {
 		log_warnx("rpc", "no interface provided");
 		goto set_port_finished;
