@@ -255,8 +255,7 @@ levent_ctl_notify(char *ifname, int state, struct lldpd_port *neighbor)
 			    sizeof(backup_p_entries));
 			memset(&neighbor->p_entries, 0,
 			    sizeof(backup_p_entries));
-			output_len = marshal_serialize(lldpd_neighbor_change,
-			    &neigh, &output);
+			output_len = lldpd_neighbor_change_serialize(&neigh, &output);
 			memcpy(&neighbor->p_entries, &backup_p_entries,
 			    sizeof(backup_p_entries));
 
@@ -405,6 +404,13 @@ levent_update_and_send(evutil_socket_t fd, short what, void *arg)
 	event_add(cfg->g_main_loop, &tv);
 }
 
+void
+levent_update_now(struct lldpd *cfg)
+{
+	if (cfg->g_main_loop)
+		event_active(cfg->g_main_loop, EV_TIMEOUT, 1);
+}
+
 void
 levent_send_now(struct lldpd *cfg)
 {
@@ -689,7 +695,7 @@ levent_schedule_cleanup(struct lldpd *cfg)
 	TAILQ_FOREACH(hardware, &cfg->g_hardware, h_entries) {
 		TAILQ_FOREACH(port, &hardware->h_rports, p_entries) {
 			next = port->p_chassis->c_ttl - (now - port->p_lastupdate);
-			if (next > 0 && next < tv.tv_sec)
+			if (next >= 0 && next < tv.tv_sec)
 				tv.tv_sec = next;
 		}
 	}
@@ -709,11 +715,21 @@ static void
 levent_send_pdu(evutil_socket_t fd, short what, void *arg)
 {
 	struct lldpd_hardware *hardware = arg;
+	int tx_interval = hardware->h_cfg->g_config.c_tx_interval;
+
 	log_debug("event", "trigger sending PDU for port %s",
 	    hardware->h_ifname);
 	lldpd_send(hardware);
 
-	struct timeval tv = { hardware->h_cfg->g_config.c_tx_interval, 0 };
+#ifdef ENABLE_LLDPMED
+	if (hardware->h_tx_fast > 0)
+		hardware->h_tx_fast--;
+
+	if (hardware->h_tx_fast > 0)
+		tx_interval = hardware->h_cfg->g_config.c_tx_fast_interval;
+#endif
+
+	struct timeval tv = { tx_interval, 0 };
 	if (event_add(hardware->h_timer, &tv) == -1) {
 		log_warnx("event", "unable to re-register timer event for port %s",
 		    hardware->h_ifname);
