@@ -37,13 +37,6 @@
 #include <netinet/if_ether.h>
 #include <pwd.h>
 #include <grp.h>
-#if defined HOST_OS_FREEBSD || \
-    defined HOST_OS_OPENBSD || \
-    defined HOST_OS_NETBSD  || \
-    defined HOST_OS_OSX
-# include <sys/param.h>
-# include <sys/sysctl.h>
-#endif
 
 static void		 usage(void);
 
@@ -220,6 +213,30 @@ lldpd_hardware_cleanup(struct lldpd *cfg, struct lldpd_hardware *hardware)
 	free(hardware);
 }
 
+static void
+lldpd_count_neighbors(struct lldpd *cfg)
+{
+#if HAVE_SETPROCTITLE
+	struct lldpd_chassis *chassis;
+	const char *neighbor;
+	unsigned neighbors = 0;
+	TAILQ_FOREACH(chassis, &cfg->g_chassis, c_entries) {
+		neighbors++;
+		neighbor = chassis->c_name;
+	}
+	neighbors--;
+	if (neighbors == 0)
+		setproctitle("no neighbor");
+	else if (neighbors == 1 && neighbor)
+		setproctitle("connected to %s", neighbor);
+	else
+		setproctitle("%d neighbor%s", neighbors,
+		    (neighbors > 1)?"s":"");
+#else
+	(void)cfg;
+#endif
+}
+
 static void
 notify_clients_deletion(struct lldpd_hardware *hardware,
     struct lldpd_port *rport)
@@ -247,7 +264,7 @@ lldpd_reset_timer(struct lldpd *cfg)
 		char save[offsetof(struct lldpd_port, p_id_subtype)];
 		memcpy(save, port, sizeof(save));
 		memset(port, 0, sizeof(save));
-		output_len = marshal_serialize(lldpd_port, port, (void**)&output);
+		output_len = lldpd_port_serialize(port, (void**)&output);
 		memcpy(port, save, sizeof(save));
 		if (output_len == -1) {
 			log_warnx("localchassis",
@@ -301,6 +318,7 @@ lldpd_cleanup(struct lldpd *cfg)
 		}
 	}
 
+	lldpd_count_neighbors(cfg);
 	levent_schedule_cleanup(cfg);
 }
 
@@ -385,8 +403,11 @@ lldpd_decode(struct lldpd *cfg, char *frame, int s,
 	if (s < sizeof(struct ether_header) + 4)
 		/* Too short, just discard it */
 		return;
+
 	/* Decapsulate VLAN frames */
-	if (((struct ether_header*)frame)->ether_type == htons(ETHERTYPE_VLAN)) {
+	struct ether_header eheader;
+	memcpy(&eheader, frame, sizeof(struct ether_header));
+	if (eheader.ether_type == htons(ETHERTYPE_VLAN)) {
 		/* VLAN decapsulation means to shift 4 bytes left the frame from
 		 * offset 2*ETHER_ADDR_LEN */
 		memmove(frame + 2*ETHER_ADDR_LEN, frame + 2*ETHER_ADDR_LEN + 4, s - 2*ETHER_ADDR_LEN);
@@ -528,6 +549,20 @@ lldpd_decode(struct lldpd *cfg, char *frame, int s,
 	agent_notify(hardware, i, port);
 #endif
 
+#ifdef ENABLE_LLDPMED
+	if (!oport && port->p_chassis->c_med_type) {
+		/* New neighbor, fast start */
+		if (hardware->h_cfg->g_config.c_enable_fast_start &&
+		    !hardware->h_tx_fast) {
+			log_debug("decode", "%s: entering fast start due to "
+			    "new neighbor", hardware->h_ifname);
+			hardware->h_tx_fast = hardware->h_cfg->g_config.c_tx_fast_init;
+		}
+
+		levent_schedule_pdu(hardware);
+	}
+#endif
+
 	return;
 }
 
@@ -784,6 +819,7 @@ lldpd_recv(struct lldpd *cfg, struct lldpd_hardware *hardware, int fd)
 	    hardware->h_ifname);
 	lldpd_decode(cfg, buffer, n, hardware);
 	lldpd_hide_all(cfg); /* Immediatly hide */
+	lldpd_count_neighbors(cfg);
 	free(buffer);
 }
 
@@ -862,32 +898,14 @@ lldpd_med(struct lldpd_chassis *chassis)
 #endif
 
 static int
-lldpd_forwarding_enabled(void)
+lldpd_routing_enabled(struct lldpd *cfg)
 {
-	int rc = 0;
-#if defined HOST_OS_LINUX
-	int f;
-	char status;
-	if ((f = priv_open("/proc/sys/net/ipv4/ip_forward")) >= 0) {
-		if ((read(f, &status, 1) == 1) && (status == '1'))
-			rc = 1;
-		close(f);
+	int routing;
+	if ((routing = interfaces_routing_enabled(cfg)) == -1) {
+		log_debug("localchassis", "unable to check if routing is enabled");
+		return 0;
 	}
-#elif defined HOST_OS_FREEBSD || defined HOST_OS_OPENBSD || defined HOST_OS_NETBSD || defined HOST_OS_OSX
-	int n, mib[4] = {
-		CTL_NET,
-		PF_INET,
-		IPPROTO_IP,
-		IPCTL_FORWARDING
-	};
-	size_t len = sizeof(int);
-	if (sysctl(mib, 4, &n, &len, NULL, 0) != -1)
-		rc = (n == 1);
-#else
-#error Unsupported OS
-#endif
-	else log_debug("localchassis", "unable to check if forwarding is enabled");
-	return rc;
+	return routing;
 }
 
 static void
@@ -900,7 +918,7 @@ lldpd_update_localchassis(struct lldpd *cfg)
 	assert(LOCAL_CHASSIS(cfg) != NULL);
 
 	/* Set system name and description */
-	if (uname(&un) != 0)
+	if (uname(&un) < 0)
 		fatal("localchassis", "failed to get system information");
 	if ((hp = priv_gethostbyname()) == NULL)
 		fatal("localchassis", "failed to get system name");
@@ -929,9 +947,9 @@ lldpd_update_localchassis(struct lldpd *cfg)
 	        }
         }
 
-	/* Check forwarding */
-	if (lldpd_forwarding_enabled()) {
-		log_debug("localchassis", "forwarding is enabled, enable router capability");
+	/* Check routing */
+	if (lldpd_routing_enabled(cfg)) {
+		log_debug("localchassis", "routing is enabled, enable router capability");
 		LOCAL_CHASSIS(cfg)->c_cap_enabled |= LLDP_CAP_ROUTER;
 	} else
 		LOCAL_CHASSIS(cfg)->c_cap_enabled &= ~LLDP_CAP_ROUTER;
@@ -994,6 +1012,7 @@ lldpd_loop(struct lldpd *cfg)
 	lldpd_update_localports(cfg);
 	log_debug("loop", "update information for local chassis");
 	lldpd_update_localchassis(cfg);
+	lldpd_count_neighbors(cfg);
 }
 
 static void
@@ -1182,6 +1201,7 @@ lldpd_main(int argc, char *argv[])
 	int i, found, advertise_version = 1;
 #ifdef ENABLE_LLDPMED
 	int lldpmed = 0, noinventory = 0;
+	int enable_fast_start = 1;
 #endif
 	char *descr_override = NULL;
 	char *platform_override = NULL;
@@ -1411,7 +1431,13 @@ lldpd_main(int argc, char *argv[])
 		cfg->g_config.c_paused = 1;
 	cfg->g_config.c_receiveonly = receiveonly;
 	cfg->g_config.c_tx_interval = LLDPD_TX_INTERVAL;
+	cfg->g_config.c_tx_hold = LLDPD_TX_HOLD;
 	cfg->g_config.c_max_neighbors = LLDPD_MAX_NEIGHBORS;
+#ifdef ENABLE_LLDPMED
+	cfg->g_config.c_enable_fast_start = enable_fast_start;
+	cfg->g_config.c_tx_fast_init = LLDPD_FAST_INIT;
+	cfg->g_config.c_tx_fast_interval = LLDPD_FAST_TX_INTERVAL;
+#endif
 #ifdef USE_SNMP
 	cfg->g_snmp = snmp;
 	cfg->g_snmp_agentx = agentx;
@@ -1455,7 +1481,7 @@ lldpd_main(int argc, char *argv[])
 #endif
 
 	/* Set TTL */
-	lchassis->c_ttl = LLDPD_TTL;
+	lchassis->c_ttl = cfg->g_config.c_tx_interval * cfg->g_config.c_tx_hold;
 
 	log_debug("main", "initialize protocols");
 	cfg->g_protocols = protos;
