@@ -62,11 +62,14 @@ struct event_base;
 
 #define SYSFS_CLASS_NET "/sys/class/net/"
 #define SYSFS_CLASS_DMI "/sys/class/dmi/id/"
-#define LLDPD_TTL		120
 #define LLDPD_TX_INTERVAL	30
+#define LLDPD_TX_HOLD          4
+#define LLDPD_TTL              LLDPD_TX_INTERVAL * LLDPD_TX_HOLD
 #define LLDPD_TX_MSGDELAY	1
 #define LLDPD_MAX_NEIGHBORS	4
 #define LLDPD_PID_FILE		"/var/run/lldpd.pid"
+#define LLDPD_FAST_TX_INTERVAL	1
+#define LLDPD_FAST_INIT	4
 
 #define USING_AGENTX_SUBAGENT_MODULE 1
 
@@ -143,6 +146,7 @@ void	 levent_hardware_add_fd(struct lldpd_hardware *, int);
 void	 levent_hardware_release(struct lldpd_hardware *);
 void	 levent_ctl_notify(char *, int, struct lldpd_port *);
 void	 levent_send_now(struct lldpd *);
+void	 levent_update_now(struct lldpd *);
 int	 levent_iface_subscribe(struct lldpd *, int);
 void	 levent_schedule_pdu(struct lldpd_hardware *);
 void	 levent_schedule_cleanup(struct lldpd *);
@@ -339,6 +343,7 @@ void interfaces_helper_vlan(struct lldpd *,
 #endif
 
 void interfaces_setup_multicast(struct lldpd *, const char *, int);
+int interfaces_routing_enabled(struct lldpd *);
 
 #ifdef HOST_OS_LINUX
 /* netlink.c */
@@ -347,4 +352,8 @@ struct interfaces_address_list *netlink_get_addresses(void);
 int netlink_subscribe_changes(void);
 #endif
 
+#ifndef HOST_OS_LINUX
+int ifbpf_phys_init(struct lldpd *, struct lldpd_hardware *);
+#endif
+
 #endif /* _LLDPD_H */
