@@ -367,6 +367,63 @@ _lldpctl_atom_get_str_config(lldpctl_atom_t *atom, lldpctl_key_t key)
 	return res?res:"";
 }
 
+static lldpctl_atom_t*
+_lldpctl_atom_set_str_config(lldpctl_atom_t *atom, lldpctl_key_t key,
+    const char *value)
+{
+	struct _lldpctl_atom_config_t *c =
+	    (struct _lldpctl_atom_config_t *)atom;
+	struct lldpd_config config;
+	char *iface_pattern = NULL;
+	char *description = NULL;
+	int rc, len;
+
+	memset(&config, 0, sizeof(struct lldpd_config));
+	len = strlen(value) + 1;
+
+	switch (key) {
+	case lldpctl_k_config_iface_pattern:
+		iface_pattern = _lldpctl_alloc_in_atom(atom, strlen(value) + 1);
+		if (!iface_pattern)
+			return NULL;
+		memcpy(iface_pattern, value, len);
+		config.c_iface_pattern = iface_pattern;
+		free(c->config->c_iface_pattern);
+		c->config->c_iface_pattern = strdup(iface_pattern);
+		break;
+	case lldpctl_k_config_description:
+		description = _lldpctl_alloc_in_atom(atom, strlen(value) + 1);
+		if (!description)
+			return NULL;
+		memcpy(description, value, len);
+		config.c_description = description;
+		free(c->config->c_description);
+		c->config->c_description = strdup(description);
+		break;
+	case lldpctl_k_config_platform:
+		description = _lldpctl_alloc_in_atom(atom, strlen(value) + 1);
+		if (!description)
+			return NULL;
+		memcpy(description, value, len);
+		config.c_platform = description;
+		free(c->config->c_platform);
+		c->config->c_description = strdup(description);
+		break;
+	default:
+		SET_ERROR(atom->conn, LLDPCTL_ERR_NOT_EXIST);
+		return NULL;
+	}
+
+	rc = _lldpctl_do_something(atom->conn,
+	    CONN_STATE_SET_CONFIG_SEND, CONN_STATE_SET_CONFIG_RECV,
+	    NULL,
+	    SET_CONFIG, &config, &MARSHAL_INFO(lldpd_config),
+	    NULL, NULL);
+	if (rc == 0) return atom;
+
+	return NULL;
+}
+
 static long int
 _lldpctl_atom_get_int_config(lldpctl_atom_t *atom, lldpctl_key_t key)
 {
@@ -384,7 +441,13 @@ _lldpctl_atom_get_int_config(lldpctl_atom_t *atom, lldpctl_key_t key)
 #ifdef ENABLE_LLDPMED
 	case lldpctl_k_config_lldpmed_noinventory:
 		return c->config->c_noinventory;
+	case lldpctl_k_config_fast_start_enabled:
+		return c->config->c_enable_fast_start;
+	case lldpctl_k_config_fast_start_interval:
+		return c->config->c_tx_fast_interval;
 #endif
+	case lldpctl_k_config_tx_hold:
+		return c->config->c_tx_hold;
 	default:
 		return SET_ERROR(atom->conn, LLDPCTL_ERR_NOT_EXIST);
 	}
@@ -408,6 +471,19 @@ _lldpctl_atom_set_int_config(lldpctl_atom_t *atom, lldpctl_key_t key,
 		config.c_tx_interval = value;
 		if (value > 0) c->config->c_tx_interval = value;
 		break;
+#ifdef ENABLE_LLDPMED
+	case lldpctl_k_config_fast_start_enabled:
+		config.c_enable_fast_start =  value?1:2;
+		c->config->c_enable_fast_start = value;
+		break;
+	case lldpctl_k_config_fast_start_interval:
+		config.c_tx_fast_interval = c->config->c_tx_fast_interval = value;
+		break;
+#endif
+	case lldpctl_k_config_tx_hold:
+		config.c_tx_hold = value;
+		if (value > 0) c->config->c_tx_hold = value;
+		break;
 	default:
 		SET_ERROR(atom->conn, LLDPCTL_ERR_NOT_EXIST);
 		return NULL;
@@ -2457,6 +2533,7 @@ struct atom_builder builders[] = {
 	  .init = _lldpctl_atom_new_config,
 	  .free = _lldpctl_atom_free_config,
 	  .get_str = _lldpctl_atom_get_str_config,
+	  .set_str = _lldpctl_atom_set_str_config,
 	  .get_int = _lldpctl_atom_get_int_config,
 	  .set_int = _lldpctl_atom_set_int_config },
 	{ atom_interfaces_list, sizeof(struct _lldpctl_atom_interfaces_list_t),
